@@ -1,5 +1,5 @@
 # IMAP folder support
-# Copyright (C) 2002 John Goerzen
+# Copyright (C) 2002-2004 John Goerzen
 # <jgoerzen@complete.org>
 #
 #    This program is free software; you can redistribute it and/or modify
@@ -104,10 +104,15 @@ class IMAPFolder(BaseFolder):
         return self.messagelist
 
     def getmessage(self, uid):
+        ui = UIBase.getglobalui()
         imapobj = self.imapserver.acquireconnection()
         try:
             imapobj.select(self.getfullname(), readonly = 1)
-            return imapobj.uid('fetch', '%d' % uid, '(BODY.PEEK[])')[1][0][1].replace("\r\n", "\n")
+            initialresult = imapobj.uid('fetch', '%d' % uid, '(BODY.PEEK[])')
+            ui.debug('imap', 'Returned object from fetching %d: %s' % \
+                     (uid, str(initialresult)))
+            return initialresult[1][0][1].replace("\r\n", "\n")
+                
         finally:
             self.imapserver.releaseconnection(imapobj)
     
@@ -145,7 +150,7 @@ class IMAPFolder(BaseFolder):
 
     def savemessage_searchforheader(self, imapobj, headername, headervalue):
         if imapobj.untagged_responses.has_key('APPENDUID'):
-            return long(imapobj.untagged_responses['APPENDUID'][0].split(' ')[1])
+            return long(imapobj.untagged_responses['APPENDUID'][-1].split(' ')[1])
 
         ui = UIBase.getglobalui()
         ui.debug('imap', 'savemessage_searchforheader called for %s: %s' % \
@@ -194,7 +199,7 @@ class IMAPFolder(BaseFolder):
                     raise ValueError
                 # This could raise a value error if it's not a valid format.
                 date = imaplib.Time2Internaldate(datetuple) 
-            except ValueError:
+            except (ValueError, OverflowError):
                 # Argh, sometimes it's a valid format but year is 0102
                 # or something.  Argh.  It seems that Time2Internaldate
                 # will rause a ValueError if the year is 0102 but not 1902,
@@ -277,6 +282,12 @@ class IMAPFolder(BaseFolder):
         self.processmessagesflags('-', uidlist, flags)
 
     def processmessagesflags(self, operation, uidlist, flags):
+        if len(uidlist) > 101:
+            # Hack for those IMAP ervers with a limited line length
+            self.processmessagesflags(operation, uidlist[:100], flags)
+            self.processmessagesflags(operation, uidlist[100:], flags)
+            return
+        
         imapobj = self.imapserver.acquireconnection()
         try:
             try:
