@@ -20,16 +20,24 @@ from offlineimap import imaplib, imapserver, repository, folder, mbnames, thread
 from offlineimap.localeval import LocalEval
 from offlineimap.threadutil import InstanceLimitedThread, ExitNotifyThread
 from offlineimap.ui import UIBase
-import re, os, os.path, offlineimap, sys, fcntl
+import re, os, os.path, offlineimap, sys
 from offlineimap.CustomConfig import CustomConfigParser
 from threading import *
 import threading
 from getopt import getopt
 
+try:
+    import fcntl
+    hasfcntl = 1
+except:
+    hasfcntl = 0
+
 lockfd = None
 
 def lock(config, ui):
-    global lockfd
+    global lockfd, hasfcntl
+    if not hasfcntl:
+        return
     lockfd = open(config.getmetadatadir() + "/lock", "w")
     try:
         fcntl.flock(lockfd, fcntl.LOCK_EX | fcntl.LOCK_NB)
@@ -38,7 +46,7 @@ def lock(config, ui):
         ui.terminate(1)
 
 def startup(versionno):
-    assert versionno == version.versionstr, "Revision of main program (%d) does not match that of library (%d).  Please double-check your PYTHONPATH and installation locations." % (revno, version.revno)
+    assert versionno == version.versionstr, "Revision of main program (%s) does not match that of library (%s).  Please double-check your PYTHONPATH and installation locations." % (versionno, version.versionstr)
     options = {}
     if '--help' in sys.argv[1:]:
         sys.stdout.write(version.cmdhelp + "\n")
@@ -47,15 +55,15 @@ def startup(versionno):
     for optlist in getopt(sys.argv[1:], 'P:1oa:c:d:l:u:h')[0]:
         options[optlist[0]] = optlist[1]
 
-    if '-h' in options:
+    if options.has_key('-h'):
         sys.stdout.write(version.cmdhelp)
         sys.stdout.write("\n")
         sys.exit(0)
     configfilename = os.path.expanduser("~/.offlineimaprc")
-    if '-c' in options:
+    if options.has_key('-c'):
         configfilename = options['-c']
-    if '-P' in options:
-        if not '-1' in options:
+    if options.has_key('-P'):
+        if not options.has_key('-1'):
             sys.stderr.write("FATAL: profile mode REQUIRES -1\n")
             sys.exit(100)
         profiledir = options['-P']
@@ -73,12 +81,12 @@ def startup(versionno):
     ui = offlineimap.ui.detector.findUI(config, options.get('-u'))
     UIBase.setglobalui(ui)
 
-    if '-l' in options:
+    if options.has_key('-l'):
         ui.setlogfd(open(options['-l'], 'wt'))
 
     ui.init_banner()
 
-    if '-d' in options:
+    if options.has_key('-d'):
         for debugtype in options['-d'].split(','):
             ui.add_debug(debugtype.strip())
             if debugtype == 'imap':
@@ -86,18 +94,18 @@ def startup(versionno):
             if debugtype == 'thread':
                 threading._VERBOSE = 1
 
-    if '-o' in options:
+    if options.has_key('-o'):
         # FIXME: maybe need a better
         for section in accounts.getaccountlist(config):
             config.remove_option('Account ' + section, "autorefresh")
 
     lock(config, ui)
 
-    if '-l' in options:
+    if options.has_key('-l'):
         sys.stderr = ui.logfile
 
     activeaccounts = config.get("general", "accounts")
-    if '-a' in options:
+    if options.has_key('-a'):
         activeaccounts = options['-a']
     activeaccounts = activeaccounts.replace(" ", "")
     activeaccounts = activeaccounts.split(",")
@@ -111,7 +119,7 @@ def startup(versionno):
     remoterepos = None
     localrepos = None
 
-    if '-1' in options:
+    if options.has_key('-1'):
         threadutil.initInstanceLimit("ACCOUNTLIMIT", 1)
     else:
         threadutil.initInstanceLimit("ACCOUNTLIMIT",
@@ -120,7 +128,7 @@ def startup(versionno):
     for reposname in config.getsectionlist('Repository'):
         for instancename in ["FOLDER_" + reposname,
                              "MSGCOPY_" + reposname]:
-            if '-1' in options:
+            if options.has_key('-1'):
                 threadutil.initInstanceLimit(instancename, 1)
             else:
                 threadutil.initInstanceLimit(instancename,
