@@ -386,7 +386,7 @@ class Blinkenlights(BlinkenBase, UIBase):
             # Key not a valid one: exit.
             return
 
-        if index > len(s.hotkeys):
+        if index >= len(s.hotkeys):
             # Not in our list of valid hotkeys.
             return
 
@@ -488,7 +488,7 @@ class Blinkenlights(BlinkenBase, UIBase):
         return s.af[accountname]
 
 
-    def _msg(s, msg, color = None):
+    def _display(s, msg, color = None):
         if "\n" in msg:
             for thisline in msg.split("\n"):
                 s._msg(thisline)
